#!/bin/sh
: Make sure we get executed by sh on all systems

platform=`uname -s`;

if [ ! -f mcs.tar ]; then
	echo "There is no tar file from which to install, perhaps you have already installed";
	echo "Please untar the downloaded file again";
	exit 1;
fi

if [ ! "$1" = 'nosu' ]; then 
	if id | grep "^uid=0(" >/dev/null 2>&1
		then # user IS superuser
       		 	echo "Commencing MyConnection Server configure as root.";
		else
       		 	echo "MyConnection Server needs to be installed as root.";
       		 	if [ "$platform" = 'Darwin' ]; then
       		 		echo "run it with 'sudo sh mcs_configure.sh'.";
				fi
       		 	exit 1;
	fi
fi

cdir=`pwd`;
echo "=========================================="
echo "What directory would you like to install MyConnection Server?";
echo " to assume $cdir, just hit <enter>";
read mdir;
if [ -z "$mdir" ]; then
	mdir=$cdir;
fi

if [ -f $mdir/vr.bin ]; then
	echo "VisualRoute install detected, please run again and install in a different directory";
	exit 1;
fi

if [ -f $mdir/vip.bin ]; then
	echo "VisualPulse install detected, please run again and install in a different directory";
	exit 1;
fi

if [ -f $mdir/mcs.sh ]; then
        echo "WARNING";
        echo " ";
        echo "MCS 9.7g and above supports Java 8.";
		echo " ";
        echo "IMPORTANT: If you are upgrading an older version than 9.7j all MCS webpages not ";
        echo "hosted on an MCS server will require 2 small HTML changes to support JAVA 8."
        echo "Please see http://www.myconnectionserver.com/signedapplet.html";
        echo " ";
        echo "Note: Once you have installed this version you will not be able to downgrade to your previous version.";
        echo " ";
        echo "Please confirm to continue (y/n)";
        read appletconfirm;
        if [ "$appletconfirm" != "y" ]; then
                exit 1;
        fi
fi

if [ -f $mdir/mcs.sh ]; then
	echo "Previous install detected, please confirm overwrite (y/n)";
	read mconfirm;
	if [ "$mconfirm" != "y" ]; then
		exit 1;
	fi
	sh $mdir/mcs.sh stop;
fi

if [ ! -d $mdir ]; then
	mkdir -m 775 -p $mdir;
fi

if [ -f libmswin32v15.jnilib ]; then
       	rm libmswin32v15.jnilib;
fi
if [ -f libmswin32v15-linux-32bit.so ]; then
       	rm libmswin32v15-linux-32bit.so;
fi
if [ -f libmswin32v15-linux-64bit.so ]; then
       	rm libmswin32v15-linux-64bit.so;
fi
if [ -f libmswin32v15-freebsd-32bit.so ]; then
       	rm libmswin32v15-freebsd-32bit.so;
fi
if [ -f libmswin32v15-freebsd-64bit.so ]; then
       	rm libmswin32v15-freebsd-64bit.so;
fi
if [ -f libmswin32v15-solaris.so ]; then
       	rm libmswin32v15-solaris.so;
fi
if [ -f libmswin32v15.jnilib ]; then
		rm libmswin32v15.jnilib;
fi

bnam=`basename $mdir`;
cd $mdir;
dat=`date +%a%M%S`;
rm -rf *.jar;
tar -xf $cdir/mcs.tar;
mv mcs.jar $dat-mcs.jar;

fdir=`pwd`;

echo "=========================================="
if [ "$platform" = 'FreeBSD' ]; then
	dirlist="/usr/local";
elif [ -d /opt ]; then
	dirlist="/usr /opt";
else
	dirlist="/usr";
fi
echo "Searching $dirlist directories for java, please wait";

if [ "$platform" = 'Darwin' ]; then
	find -H $dirlist -name java -print > /tmp/java.$$;
else
	find $dirlist -type f -name java -print > /tmp/java.$$;
fi
if [ ! -s /tmp/java.$$ ]; then
	echo "MyConnection Server requires a Java VM, but was unable to find one installed.";
	echo " ";
	echo "Please visit http://java.sun.com to download and install a free one.";
	echo "After you have installed a JVM, try this script again with:-";
	echo "'sh $cdir/mcs_configure.sh'";
	echo "  for further information please review readme.txt.";
	exit 1;
fi

dirnam="";
jconfirm="";
for i in `cat /tmp/java.$$`
do
	fulljvm=`$i -classpath . TestJVM`;
	testjvm=`$i -classpath . TestJVM 2>/dev/null | awk '{ print $1 }'`;
	if [ "$testjvm" = "Correct" ]; then
		testversion=`$i -classpath . TestJVM 2>/dev/null | awk '{ print $2 }'`;
		echo "$testversion $i" >> /tmp/javaversion.$$;
		echo "java from $i is valid, result $fulljvm";
	else
		echo "java from $i is not valid, result $fulljvm";
	fi
	echo " ";
done

if [ -f /tmp/java.$$ ]; then 
	rm /tmp/java.$$;
fi

if [ ! -s /tmp/javaversion.$$ ]; then
	echo "=========================================="
	echo "MyConnection Server is only supported with the Sun or IBM JVM.";
	echo " ";
	echo "Please visit http://java.sun.com to download and install a Sun JVM.";
	echo "After you have installed the Sun JVM, try this script again.";
	echo "The JVM will be looked for by this script in the /usr and /opt directories.";
	echo " ";
	exit 1;
 else
	jconfirm=`sort -r /tmp/javaversion.$$ | head -n 1 | awk '{ print $2 }'`
	dirnam=`dirname $jconfirm`;
	echo "$dirnam is to be used";
fi

if [ -f /tmp/javaversion.$$ ]; then 
	rm /tmp/javaversion.$$;
fi

if [ -f start_mcs.sh ]; then 
	rm start_mcs.sh;
fi
echo "#!/bin/sh" > start_mcs.sh;
echo " " >> start_mcs.sh;
echo ": Make sure we get executed by sh on all systems" >> start_mcs.sh;
if [ "$1" = 'nosu' ]; then 
	echo "sh $fdir/mcs.sh start nosu" >> start_mcs.sh;
else
	echo "sh $fdir/mcs.sh start" >> start_mcs.sh;
fi
chmod +x start_mcs.sh;

if [ -f stop_mcs.sh ]; then 
	rm stop_mcs.sh;
fi
echo "#!/bin/sh" > stop_mcs.sh;
echo " " >> stop_mcs.sh;
echo ": Make sure we get executed by sh on all systems" >> stop_mcs.sh;
if [ "$1" = 'nosu' ]; then 
	echo "sh $fdir/mcs.sh stop nosu" >> stop_mcs.sh;
else
	echo "sh $fdir/mcs.sh stop" >> stop_mcs.sh;
fi
chmod +x stop_mcs.sh;

if [ -f mcs.sh ]; then 
	rm mcs.sh;
fi

echo "#!/bin/sh" > mcs.sh;
echo "# " >> mcs.sh;
echo "# $bnam	This shell script starts and stops $bnam" >> mcs.sh;
echo "# chkconfig: 2345 85 10" >> mcs.sh;
echo "# description: MyConnection Server Server tests upload and download speeds" >> mcs.sh;
echo " " >> mcs.sh;
echo ": Make sure we get executed by sh on all systems" >> mcs.sh;
echo " " >> mcs.sh;
echo "MSHOME=$fdir" >> mcs.sh;
echo "PATH=${dirnam}:/usr/bin:/bin:$fdir:." >> mcs.sh;
echo "export MSHOME PATH" >> mcs.sh;
cat PartTwo.sh >> mcs.sh;
rm PartTwo.sh mcs.tar;
chmod +x mcs.sh;

if [ -x /usr/sbin/update-rc.d ]; then
        echo "=========================================="
        echo "Do you want MyConnection Server to automatically run everytime the machine starts (y/n)?";
        read cservice;
        dest="/etc/init.d";
        echo "Checking if service exists";
        if [ -f $dest/$bnam ]; then
                echo "Removing existing $bnam service";
                rm /etc/init.d/$bnam
                /usr/sbin/update-rc.d -f $bnam remove;
        fi
        if [ "$cservice" = "y" ]; then
                cp mcs.sh $dest/$bnam;
                /usr/sbin/update-rc.d $bnam start 90 2 3 4 5 . stop 90 0 1 6 .;
        fi
elif [ -x /sbin/chkconfig ]; then
	echo "=========================================="
	echo "Do you want MyConnection Server to automatically run everytime the machine starts (y/n)?";
	read cservice;
	if [ -f /etc/debian_version ]; then
		dest="/etc/init.d";
	elif [ -f /etc/SuSE-release ]; then
		dest="/etc/init.d";
	else
		dest="/etc/rc.d/init.d";
	fi
	if [ "$1" = 'nosu' ]; then 
		cp mcs.sh /opt/app/mcs/init;
	elif [ "$cservice" = "y" ]; then
		cp mcs.sh $dest/$bnam;
		chkconfig --add $bnam;
	else
		echo "Checking if service exists";
		if [ -f $dest/$bnam ]; then
			echo "Removing existing $bnam service";
			chkconfig --del $bnam;
		fi
	fi
fi
echo "=========================================="

if [ ! "$1" = 'nosu' ]; then 
	if [ "$platform" = 'Darwin' ]; then
		sudo sh $fdir/start_mcs.sh;
	else
		sh $fdir/start_mcs.sh;
	fi
fi
